==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/Acl/Operations.php <==
<?php
namespace Claromentis\Core\Acl;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] ?: array()) + array("_d706c160e4" . "5bf7434fff8" . "2a5976f0e19" => base64_decode("YXJyYXl" . "fa2V5cw" . "=="), "_f73dab606630b388645" . "c4f7d3fbb13bb" => base64_decode("YXJyYXlfb" . "WVyZ2U="), "_bd71c3b5c201fc11db82ed14" . "ce424de5" => base64_decode("aW5fYXJyYXk" . "="));






class Operations
{
    
    
    
    
    
    
    
    public function Merge(Acl $_3ebac1a80bb918c6b638065c0a346183, Acl $_35efbba9f47cbb5382600ed6490e96cd)
    {
        $_4e839ed770bd0a11b52c962ae00d2a7d = $_3ebac1a80bb918c6b638065c0a346183->GetRights();
        $_b20289dbb42178b8c815d72c759190e6 = $_35efbba9f47cbb5382600ed6490e96cd->GetRights();
        foreach (PermOClass::$all as $_0f0ee93b89a6a83a69ad4a5909c20cb0) {
            foreach ($_b20289dbb42178b8c815d72c759190e6[$_0f0ee93b89a6a83a69ad4a5909c20cb0] as $_1681112f53987f6e29f76d473c53a8f4 => $perms) {
                if (!isset($_4e839ed770bd0a11b52c962ae00d2a7d[$_0f0ee93b89a6a83a69ad4a5909c20cb0][$_1681112f53987f6e29f76d473c53a8f4])) {
                    $_4e839ed770bd0a11b52c962ae00d2a7d[$_0f0ee93b89a6a83a69ad4a5909c20cb0][$_1681112f53987f6e29f76d473c53a8f4] = 0;
                }
                $_4e839ed770bd0a11b52c962ae00d2a7d[$_0f0ee93b89a6a83a69ad4a5909c20cb0][$_1681112f53987f6e29f76d473c53a8f4] |= $perms;
            }
        }
        $_3ebac1a80bb918c6b638065c0a346183->Hydrate($_4e839ed770bd0a11b52c962ae00d2a7d);
    }
    
    
    
    
    
    
    
    
    
    public function Restrict(Acl $_1bd6e5a007d5639e67837f0567493081, Acl $_568fcb2872723a3ebac6afca64f9238e)
    {
        $_1ac0335a1f605e216d9ffde5545a81e3 = $_568fcb2872723a3ebac6afca64f9238e->Get(PermOClass::ALL);
        $_f365d394f839fddd4250d517ee1ca5ea = $_568fcb2872723a3ebac6afca64f9238e->Get(PermOClass::PUBLIC_);
        if (!$_f365d394f839fddd4250d517ee1ca5ea) {
            $_1bd6e5a007d5639e67837f0567493081->Delete(PERM_VIEW, PermOClass::PUBLIC_);
        }
        if (!$_1ac0335a1f605e216d9ffde5545a81e3) {
            $_1bd6e5a007d5639e67837f0567493081->Delete(PERM_VIEW, PermOClass::ALL);
        }
        if (!$_1ac0335a1f605e216d9ffde5545a81e3 && !$_f365d394f839fddd4250d517ee1ca5ea) {
            foreach (PermOClass::$all as $_0f0ee93b89a6a83a69ad4a5909c20cb0) {
                $_df6c50b1e54f22297b5ec4755a99e677 = $this->GetOClassIdsForChild($_568fcb2872723a3ebac6afca64f9238e, $_0f0ee93b89a6a83a69ad4a5909c20cb0);
                if ($_df6c50b1e54f22297b5ec4755a99e677 === null) {
                    continue;
                }
                
                
                foreach ($_1bd6e5a007d5639e67837f0567493081->GetOwnersList(0, $_0f0ee93b89a6a83a69ad4a5909c20cb0) as $_1681112f53987f6e29f76d473c53a8f4) {
                    if (!$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_bd71c3b5c201fc11db82ed14ce424" . "de5"]($_1681112f53987f6e29f76d473c53a8f4, $_df6c50b1e54f22297b5ec4755a99e677)) {
                        $_1bd6e5a007d5639e67837f0567493081->Delete(PERM_VIEW, $_0f0ee93b89a6a83a69ad4a5909c20cb0, $_1681112f53987f6e29f76d473c53a8f4);
                    }
                }
            }
        }
        return true;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function GetOClassIdsForChild(Acl $acl, $_0f0ee93b89a6a83a69ad4a5909c20cb0)
    {
        if (!$acl->object_id || $acl->Has(PERM_VIEW, PERM_OCLASS_ALL)) {
            $_9cee5807b5bab08d25cd4213e63cb764 = null;
        } else {
            if ($_0f0ee93b89a6a83a69ad4a5909c20cb0 == PERM_OCLASS_INDIVIDUAL) {
                $_9cee5807b5bab08d25cd4213e63cb764 = $acl->GetIndividualsList(PERM_VIEW);
            } elseif ($_0f0ee93b89a6a83a69ad4a5909c20cb0 == PERM_OCLASS_GROUP || $_0f0ee93b89a6a83a69ad4a5909c20cb0 == PERM_OCLASS_GROUPTREE) {
                $_a523ddfe502a2d6e090750f9e2f4f5a1 = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_d706c160e45bf7434fff82" . "a5976f0e19"](\UserGroup::GetAllSubgroups($acl->GetOwnersList(PERM_VIEW, PERM_OCLASS_GROUPTREE)));
                $_9cee5807b5bab08d25cd4213e63cb764 = $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_f73dab606630b388645c4f7d3" . "fbb13bb"]($acl->GetOwnersList(PERM_VIEW, PERM_OCLASS_GROUP), $_a523ddfe502a2d6e090750f9e2f4f5a1);
            } else {
                $_9cee5807b5bab08d25cd4213e63cb764 = $acl->GetOwnersList(PERM_VIEW, $_0f0ee93b89a6a83a69ad4a5909c20cb0);
            }
        }
        return $_9cee5807b5bab08d25cd4213e63cb764;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/Acl/Operations.php <==
<?php
namespace Claromentis\Core\Acl;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] ?: array()) + array("_f73dab606630b" . "388645c4f7d3fb" . "b13bb" => base64_decode("YXJyYXlfbWV" . "yZ2U="), "_d706c160e" . "45bf7434ff" . "f82a5976f0" . "e19" => base64_decode("YXJyYXlfa2V" . "5cw=="), "_bd71c3b5c201" . "fc11db82ed14c" . "e424de5" => base64_decode("aW5fYXJ" . "yYXk="));






class Operations
{
    
    
    
    
    
    
    
    public function Merge(Acl $_3ebac1a80bb918c6b638065c0a346183, Acl $_35efbba9f47cbb5382600ed6490e96cd)
    {
        $_4e839ed770bd0a11b52c962ae00d2a7d = $_3ebac1a80bb918c6b638065c0a346183->GetRights();
        $_b20289dbb42178b8c815d72c759190e6 = $_35efbba9f47cbb5382600ed6490e96cd->GetRights();
        foreach (PermOClass::$all as $_0f0ee93b89a6a83a69ad4a5909c20cb0) {
            foreach ($_b20289dbb42178b8c815d72c759190e6[$_0f0ee93b89a6a83a69ad4a5909c20cb0] as $_1681112f53987f6e29f76d473c53a8f4 => $perms) {
                if (!isset($_4e839ed770bd0a11b52c962ae00d2a7d[$_0f0ee93b89a6a83a69ad4a5909c20cb0][$_1681112f53987f6e29f76d473c53a8f4])) {
                    $_4e839ed770bd0a11b52c962ae00d2a7d[$_0f0ee93b89a6a83a69ad4a5909c20cb0][$_1681112f53987f6e29f76d473c53a8f4] = 0;
                }
                $_4e839ed770bd0a11b52c962ae00d2a7d[$_0f0ee93b89a6a83a69ad4a5909c20cb0][$_1681112f53987f6e29f76d473c53a8f4] |= $perms;
            }
        }
        $_3ebac1a80bb918c6b638065c0a346183->Hydrate($_4e839ed770bd0a11b52c962ae00d2a7d);
    }
    
    
    
    
    
    
    
    
    
    public function Restrict(Acl $_1bd6e5a007d5639e67837f0567493081, Acl $_568fcb2872723a3ebac6afca64f9238e)
    {
        $_1ac0335a1f605e216d9ffde5545a81e3 = $_568fcb2872723a3ebac6afca64f9238e->Get(PermOClass::ALL);
        $_f365d394f839fddd4250d517ee1ca5ea = $_568fcb2872723a3ebac6afca64f9238e->Get(PermOClass::PUBLIC_);
        if (!$_f365d394f839fddd4250d517ee1ca5ea) {
            $_1bd6e5a007d5639e67837f0567493081->Delete(PERM_VIEW, PermOClass::PUBLIC_);
        }
        if (!$_1ac0335a1f605e216d9ffde5545a81e3) {
            $_1bd6e5a007d5639e67837f0567493081->Delete(PERM_VIEW, PermOClass::ALL);
        }
        if (!$_1ac0335a1f605e216d9ffde5545a81e3 && !$_f365d394f839fddd4250d517ee1ca5ea) {
            foreach (PermOClass::$all as $_0f0ee93b89a6a83a69ad4a5909c20cb0) {
                $_df6c50b1e54f22297b5ec4755a99e677 = $this->GetOClassIdsForChild($_568fcb2872723a3ebac6afca64f9238e, $_0f0ee93b89a6a83a69ad4a5909c20cb0);
                if ($_df6c50b1e54f22297b5ec4755a99e677 === null) {
                    continue;
                }
                
                
                foreach ($_1bd6e5a007d5639e67837f0567493081->GetOwnersList(0, $_0f0ee93b89a6a83a69ad4a5909c20cb0) as $_1681112f53987f6e29f76d473c53a8f4) {
                    if (!$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_bd71c3b5c201fc11db82ed14ce42" . "4de5"]($_1681112f53987f6e29f76d473c53a8f4, $_df6c50b1e54f22297b5ec4755a99e677)) {
                        $_1bd6e5a007d5639e67837f0567493081->Delete(PERM_VIEW, $_0f0ee93b89a6a83a69ad4a5909c20cb0, $_1681112f53987f6e29f76d473c53a8f4);
                    }
                }
            }
        }
        return true;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function GetOClassIdsForChild(Acl $acl, $_0f0ee93b89a6a83a69ad4a5909c20cb0)
    {
        if (!$acl->object_id || $acl->Has(PERM_VIEW, PERM_OCLASS_ALL)) {
            $_9cee5807b5bab08d25cd4213e63cb764 = null;
        } else {
            if ($_0f0ee93b89a6a83a69ad4a5909c20cb0 == PERM_OCLASS_INDIVIDUAL) {
                $_9cee5807b5bab08d25cd4213e63cb764 = $acl->GetIndividualsList(PERM_VIEW);
            } elseif ($_0f0ee93b89a6a83a69ad4a5909c20cb0 == PERM_OCLASS_GROUP || $_0f0ee93b89a6a83a69ad4a5909c20cb0 == PERM_OCLASS_GROUPTREE) {
                $_a523ddfe502a2d6e090750f9e2f4f5a1 = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_d706c160e" . "45bf7434ff" . "f82a5976f0" . "e19"](\UserGroup::GetAllSubgroups($acl->GetOwnersList(PERM_VIEW, PERM_OCLASS_GROUPTREE)));
                $_9cee5807b5bab08d25cd4213e63cb764 = $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_f73dab60663" . "0b388645c4f7" . "d3fbb13bb"]($acl->GetOwnersList(PERM_VIEW, PERM_OCLASS_GROUP), $_a523ddfe502a2d6e090750f9e2f4f5a1);
            } else {
                $_9cee5807b5bab08d25cd4213e63cb764 = $acl->GetOwnersList(PERM_VIEW, $_0f0ee93b89a6a83a69ad4a5909c20cb0);
            }
        }
        return $_9cee5807b5bab08d25cd4213e63cb764;
    }
}
